% AIR_SEA: introduction to the AIR_SEA toolbox.
%
%              AIR_SEA TOOLBOX (Version 1.0; March 17, 1997)
%
% 1) Introduction: Welcome to the AIR_SEA toolbox, a collection of MATLAB
% programs (m-files) which can be used to compute surface wind stress and 
% heat flux components from buoy and shipboard atmospheric and near-surface
% oceanographic time series measurements. All m-files include a header
% which describes the mfile's function, input and output variables, and 
% key references when important. They have been written for use with 
% MATLAB for PC version 4.x and MATLAB for Unix workstations. 
%
% 2) Conventions:  While not required for many m-files, it is generally
% assumed that the input time series of measured variables are hourly 
% averaged column or row vectors and the other input variables are scalars, 
% all expressed in MKS units. Two time conventions are used: a) decimal 
% Julian yearday where 0000 UT Jan 1 equals 0.0, and b) calender yearday 
% where Jan 1 equals 1. The choice of which convention is used is 
% internally consistent between m-files.
%
% 3) Programs used to compute heat flux components:
%
%    Shortwave flux:
%
%        SWHF: computes net sw flux into ocean and albedo. Uses 
%              SORADNA1 to compute solar altitude and no-sky 
%              insolation, needed to estimate albedo using ALBEDO.
%
%    Longwave flux:
%
%        LWHF: computes net lw flux into ocean when downward 
%              lw radiation is measured.
%        
%        BERLIAND: uses Berliand and Berliand (1952) formulation
%              to estimate net lw flux into ocean when downward 
%              lw radiation is NOT measured. Uses REEDCF, BINAVG,
%              CLOUDFAC, NSUNANG, and CLSKSWR to estimate daily 
%              mean cloud cover and effect on net lw flux.
%
%    Sensible and latent fluxs:
%
%        HFBULKTC: uses a simplified version of Fairall et al (1996)
%              TOGA/COARE code to compute sensible and latent heat 
%              fluxes into ocean. Uses VISCAIR and QSAT to compute
%              air viscosity and saturation specific humidity, CDNTC 
%              the neutral drag coefficient, and PSIUTC and PSITTC 
%              to adjust the different transfer coefficients to the 
%              measurement heights. This mfile also returns other 
%              related variables (e.g., the Monin Obukov height L,
%              Stanton number, etc.).
%
%        SLHFTC: includes ocean surface current and HFBULKTC to compute
%              sensible and latent heat fluxes into ocean.
%
% 4) Programs used to compute wind stress:
%
%    Neutral conditions:     
%
%        STRESSLP: computes the neutral wind stress following 
%              Large and Pond (1981).
%
%        STRESSTC: computes the neutral wind stress following
%              Smith (1988). Uses VISCAIR to compute air viscosity.
%
%    Non-neutral conditions:
%
%        HFBULKTC: uses simplified version of Fairall et al (1996)
%              TOGA/COARE code to compute surface wind stress amplitude. 
%
%        SLHFTC: includes ocean surface current and HFBULKTC to 
%              compute surface wind stress amplitude.
%
% 5) Programs used to estimate wave effects on the measured wind speed:
% 
%        WAVEDIST: estimate true wind speed at 10-m height.
%        WAVEDIS1: estimate true wind speed at measurement height.
%        OMEGALMC: estimates wave effect on wind log profile.
%        CDNVERA: computes neutral drag coefficient following Vera (1983).
%
%        See WDNOTES for additional information.
%
% 6) Other useful programs:
%
%        SUNRISE: computes GMT time of sunrise.
%        SUNSET: computes GMT time of sunset.
%        DAVEALB: computes daily mean albedo.
%        GREG2: converts decimal yearday into Julian calendar day.
%        JULIANMD: converts Gregorian calendar dates to decimal Julian day
%                  for days beginning at midnight UT
%        YEARDAY: converts calender month and day into yearday.
%        CDNLP: computes neutral Cd following Large and Pond (1981).
%        CDNTC: computes neutral Cd following Smith (1988).
%        CDNVERA: computes neutral Cd following Vera (1983).
%
% 7) See CONTENTS for listing of all m-files in this toolbox.
%
% 8) The initial assembly of this toolbox has been a collaborative effort
%    by Bob Beardsley (WHOI), Ed Dever (SIO), Steve Lentz (WHOI), Jim 
%    Edson (WHOI), and Dick Payne (WHOI), with additional input from 
%    Steve Anderson (WHOI), Jay Austin (WHOI), Chris Fairall (NOAA),
%    Carl Friehe (UCI), Bill Large (NCAR), Dave Rogers (SIO), Rich 
%    Signell (USGS), and Bob Weller (WHOI). Their input was very useful. 
%    
%    Please contact Bob Beardsley at rbeardsley@whoi.edu with questions 
%    and comments, especially concerning bugs (and their possible fixes), 
%    ideas for additional m-files, plus any m-files which you want to 
%    contribute to this toolbox. Your help in improving this toolbox will
%    be greatly appreciated.
%
%    As new or/or improved m-files are developed for this toolbox, they 
%    will be added to the AIR_SEA toolbox folder located at the SEA-MAT 
%    Web site (crusty.usgs.gov/sea-mat/).  SEA-MAT is a collection of 
%    MATLAB mfiles for the display and analysis of oceanographic data.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

