  function bindat = binave(data,r)
% BINAVE: averages vector data in bins of length r.
% bindat=BINAVE(data,r) computes an average vector of the vector 
% data in bins of length r.  The last bin is omitted if it contains
% less than r elements. Useful for computing daily average time 
% series (with r=24 for hourly data).
%
%   INPUT:   data - data vector
%            r - number of elements in bin to be averaged
%
%   OUTPUT:  bindat - bin-averaged vector
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% check input
if nargin < 2
   error('Not enough input arguments.')
end
if abs(r-fix(r)) > eps
   error('Bin size R must be a positive integer.')
end
if fix(r) == 1
	bindat = data;
	return
end
if r <= 0
	error('Bin size R must be a positive integer.')
end

[N,M]=size(data);
if N==1
  data=data';
end

% compute bin averaged series
l = length(data)/r;
l = fix(l);
bindat = zeros(l,1);
for i=1:l
  bindat(i) = mean(data(r*(i-1)+1:i*r));
end

if N==1
  bindat=bindat';
end

end

