  function cd=cdnlp(sp,z)
% CDNLP: computes neutral drag coefficient following Large&Pond (1981).
% cd = CDNLP(sp,z) computes the neutral drag coefficient given the wind
% speed at height z following Large and Pond (1981), J. Phys. Oceanog.,
% 11, 324-336. Assumes z a fixed scalar.
%
%   INPUTS: sp - wind speed (m/s)
%           z - measurement height (m)
%
%   OUTPUT: cd - neutral drag coefficient
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set constants
k=.4;
a=log(z./10)./k;

[N,M]=size(sp);
if N==1
  sp=sp';
end
L=length(sp);
cd=zeros(L,1);

for m=1:L;
% iterate to find wind speed at 10m
uold=0.;
for j=1:10;
     if uold < 10.15385
       c=.001*1.15;
     else
       c=.001*(0.49+0.065*uold);
     end
   unew=sp(m)./(1.+a*sqrt(c));
     if (abs(unew-uold)) < .001
       break
     else
       uold=unew;
     end
 end
% compute cd using 10m sp
if unew < 10.15385
     cd(m)=.001*1.15;
   else
     cd(m)=.001*(0.49+0.065*unew);
end

if N==1
  cd=cd';
end
 
end

