  function cd=cdntc(sp,z,Ta)
% CTDTC: computes the neutral drag coefficient following Smith (1988).
% cd = CDNTC(sp,z,Ta) computes the neutral drag coefficient given the 
% wind speed and air temperature at height z following Smith (1988),
% J. Geophys. Res., 93, 311-326. Assumes sp and Ta are both column 
% or row vectors and z a fixed scalar.
%
%   INPUT:  sp - wind speed (m/s)
%           z - measurement height (m)
%           Ta - air temperature (deg C)
%
%   OUTPUT: cd - drag coefficient
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% compute constants
k=.4;
g=9.8;

[N,M]=size(Ta);
if N==1
  Ta=Ta';
  sp=sp';
end
visc=viscair(Ta);

% remove any sp==0 to prevent division by zero
i=find(sp==0);
sp(i)=.1.*ones(length(i),1);

% initial guess
ustar=.036.*sp;

% iterate to find z0 and ustar
for j=1:10;
z0=.011.*ustar.^2./g +.11*visc./ustar;
ustar=sp.*(k./log(z./z0));
end

cd=(k./log(z./z0)).^2;

if N==1
  cd=cd';
end
end

