  function cd=cdnvera(sp10)
% CDNVERA: computes neutral drag coefficient following Vera (1983).
% cd = CDNVERA(sp10) computes the neutral drag coefficient given the wind
% speed at 10 m using the expression for friction velocity ustar derived 
% by E. Vera (1983) and published as eqn. 8 in Large, Morzel, and Crawford
% (1995), J. Phys. Oceanog., 25, 2959-2971. Range of fit to data is 1 to
% 25 m/s.
%
%   INPUT:  sp10 - wind speed (m/s) at 10 m
%
%   OUTPUT: cd - neutral drag coefficient at 10 m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

S1=sp10;
S2=S1.^2;
S3=S1.^3;
a=2.717;
b=0.142;
c=0.0764;

ustar2=0.001.*(a.*S1+b.*S2+c.*S3);
cd=ustar2./S2;
end

