  function cf=cloudfac(yd,lat,davesw)
% CLOUDFAC: computes daily mean cloud factor following Reed (1977).
% cf=CLOUDFAC(yd,lat,davesw) computes the daily average cloud factor 
% based on Reed (1977), J. Phys. Ocean., 7, 482-485.  Assumes year is 
% not a leap year. If yd is negative, then yd=yd+365. 
%
%   INPUT:  yd - yearday (e.g., Jan 10th is 10)
%           lat - latitude (decimal deg)
%           davesw - average measured insolation (W/m^2)
%
%   OUTPUT: cf - daily average cloud factor 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% convert to column vectors
[N,M]=size(davesw);
if N==1
  davesw=davesw';
  yd=dy';
end

% check if yd is negative
ind=find(yd<0);
yd(ind)=yd(ind)+365;
% truncate to integer yearday for use with formula
yd=fix(yd);

% determine noon solar altitude
nsa=nsunang(yd,lat);

% compute ratio of observed to clear sky insolation
cssw=clskswr(yd,lat);
x=davesw./cssw;
% correct for measurement error
ind1=find(x>1);
x(ind1)=ones(length(ind1),1);

% compute cloud factor
cf=(1-x+.0019.*nsa)./.62;
ind2=find(cf>1);
cf(ind2)=ones(length(ind2),1);
ind3=find(cf<0.3);
cf(ind3)=zeros(length(ind3),1);

% reconvert if necessary
if N==1
  cf=cf';
end

end

