  function daalb=davealb(alb,dsw)
% DAVEALB: computes daily average albedo.
% daalb=DAVEALB(alb,dsw) computes the daily average albedo from hourly
% albedo and insolation time series. Assumes input series starts at 
% local midnight so that daylight occurs in middle of day.
%
%   INPUT:  alb - albedo
%           dsw - insolation (W/m^2)
%
%   OUTPUT: daalb - daily average albedo
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[N,M]=size(dsw);
if N==1
   dsw=dsw';
   alb=alb';
end

K=length(alb);

L=fix(K./24);
y=zeros(L,1);
for j=1:L
  jl=24.*(j-1) +1;
  ju=jl+23;
  xa=alb(jl:ju);
  xs=dsw(jl:ju);
  xas=xa.*xs;
  ind=find(finite(xas));
  y(j)=sum(xas(ind))./sum(xs(ind));
end
if N==1
   y=y';
end

daalb=y;
end

