  function etadave = krausscf(yd,yr,swr,lat,long)
% KRAUSSCF: estimates daily mean cloud cover following Krauss.
% etadave = KRAUSSCF(yd,yr,swr,lat,long estimates daily averaged cloud 
% cover using Krauss's formula (ref????). Input time series should be
% hourly column vectors. Output is hourly with a 24-hr box car shape.
%
%   INPUT:  yd  -  yearday  (e.g., 0000Z Jan 1 is 0.0)
%           yr  -  year (e.g., 1995)
%           swr -  measured insolation (W/m^2)
%           lat -  latitude (decimal deg)
%           long - longitude (decimal deg) (west is positive)
%
%   OUTPUT: etadave - daily averaged cloud cover
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[m,n] = size(swr);
% set constants
gamma = 0.87;  % single value for atmospheric transmission coefficient
k = 0.35;  % value for latitude dependent constant
[z,sorad] = soradna1(yd,yr,long,lat);
zrad = pi*z/180;
swmax = sorad.*gamma.^csc(zrad);
day = find(sorad>0);
swmday = NaN*ones(length(swmax),1);
swday = swmday;
swmday(day) = swmax(day);
swday(day) = swr(day);
num = max(1-swday./swmday,0); % minimum of 0 for swday > soradday which
                              % could occur for real gamma > 0.87
eta = num/(1 - k);
etaday = reshape(eta,24,length(eta)/24);
fin = finite(etaday);
[m2 n2] = size(etaday);
fin = finite(etaday);
etadave = NaN*ones(n2,1);
for i=1:n2
  etadave(i) = mean(etaday(fin(:,i),i));
end
etadave = min(etadave,1);
if n== 1
  etadave = etadave*ones(1,24);
  etadave = reshape(etadave',m,1);
elseif m==1
  etadave = ones(24,1)*etadave;
  etadave = reshape(etadave,1,n);
end


