  function qlw=lwhf(Ts,dlw,dsw)
% LWHF: computes net longwave heat flux following Dickey et al (1994).
% qlw=LWHF(Ts,dlw) computes the net longwave heat flux into the ocean.
% Following Dickey et al (1994), J. Atmos. Oceanic Tech., 11, 1057-1078,
% the incident longwave flux is corrected for sensor heating due to
% insolation. The surface emissivity is set at 0.98 based on Katsaros
% (1990), In: Surface Waves and Fluxes, ed. Geernaert and Plant, 672-701.
%
%   INPUT:  Ts  - sea surface temperature (deg C)
%           dlw - (measured) downward longwave flux (W/m^2)
%           dsw - (measured) insolation (W/m^2)
%
%   OUTPUT: qlw - net longwave heat flux (W/m^2)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% convert degC to degK
ts=Ts+273.16;

% constants
emis=0.98;
sig=5.6697./(10^8);

% correct dlw for insolation
dlwc=dlw-0.036.*dsw;

% compute upward gray-body longwave flux
lwup=-emis.*sig.*(ts.^4);

% compute net flux
qlw=lwup + emis.*dlwc;

end

