  function y=psittc(zet)
% PSITTC: computes potential temperature profile following TOGA/COARE.
% y=PSITTC(zet) computes the turbulent potential temperature profile 
% function given zet = (z/L), L the Monin-Obukoff length scale, following 
% Edson and Fairall TOGA COARE code (version 2.0), as modified to use
% Rogers' weighting factor to combine the Dyer and free convective 
% forms for unstable conditions. 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M=length(zet);
c13=1.0./3.0;
sq3=sqrt(3.0);
y=-4.7.*zet;

j=find(zet<0);
zneg=zet(j);

  x=(1-16.0.*zneg).^0.25;
  y1=2.0*log((1+x.^2)./2);

  x=(1-12.87*zneg).^c13;
  y2=1.5.*log((x.^2+x+1)./3.0) - sq3.*atan((2.*x+1)./sq3) + pi./sq3;

  F=1.0./(1+zneg.^2);
  y(j)=F.*y1 + (1-F).*y2;

end

