  function c = reedcf(yd,lat,swr);
% REEDCF: computes daily mean cloud cover following Reed (1977).
% c = REEDCF(yd,lat,dsw) computes daily averaged cloud cover c from
% yearday, latitude, and insolation following Reed (1977), J. Phys. 
% Oceanog., 7, 482-485. Assumes hourly input series are either both 
% column or both row vectors of equal length. c is output as a boxcar 
% function with c constant over a 24 hr period.
%
%   INPUT:  yd  - yearday (e.g., Jan 10 is yd=10)
%           lat - latitude (decimal deg)
%           dsw - (measured) insolation (W/m^2) 
%
%   OUTPUT: c - daily averaged cloud cover
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Determine if input is either row or column vectors
[m,n] = size(dsw);

% First daily average swr and yd
davesw = binavg(dsw,24);
daveyd = binavg(yd,24);

% estimate daily averaged cloud factor
c=cloudfac(daveyd,lat,davesw);
% cloudfac always outputs a column vector, if initial input is
% row vector, convert cf to row vector
if m==1
  c  = c';
end

% convert daily averaged cloudfactor to boxcar function
if n== 1
  c = c*ones(1,24);
  c = reshape(c',m,1);
elseif m==1
  c = ones(24,1)*c;
  c = reshape(c,1,n);
end

