  function sp2=spshfttc(sp1,z1,z2,Ta)
% SPSHFTTC: adjusts wind speed from z1 to z2 following Smith (1988).
% sp2 = SPSHFTTC(sp1,z1,z2,Ta) shifts the wind speed sp1 measured at z1 to
% z2 using the neutral drag coefficient given the wind speed and air
% temperature at height z following Smith (1988), J. Geophys. Res., 93,
% 311-326. Assumes z1 and z2 scalars. Ta may be a constant. 
%
%   INPUT:  sp1 - measured wind speed (m/s)
%           z1 - measurement height (m)
%           z2 - desired height (m)
%           Ta - air temperature (deg C)
%
%   OUTPUT: sp2 - predicted wind speed 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set constants
k=.4;
a=log(z1./10)./k;
b=log(z2./z1)./k;

[N,M]=size(sp1);
if N==1
   sp1=sp1';
   Ta=Ta';
end

% find cd and ustar
cd=cdntc(sp1,z1,Ta);
sp10=sp1./(1+a.*sqrt(cd));
ustar=sqrt(cd).*sp10;

% compute sp2
sp2=sp1+b.*ustar;
if N==1
   sp2=sp2';
end
end

