  function sp2=spshftve(sp1,z1,z2)
% SPSHFTVE: adjusts wind speed from z1 to z2 following Vera (1983).
% sp2 = SPSHFTVE(sp1,z1,z2) shifts the wind speed sp1 measured at z1 to
% z2 using the neutral drag law of Vera (1983) [see Large, Morzel, 
% and Crawford (1995), J. Phys. Oceanog., 25, 2959-2971 (eqn. 8)]. 
% Assumes z1 and z2 scalars.
%
%   INPUT:  sp1 - measured wind speed (m/s) 
%           z1 - measurement height (m)
%           z2 - desired height (m) of sp2
%
%   OUTPUT: sp2 - predicted wind speed (m/s)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set constants
k=.4;
a=log(z1./10)./k;
b=log(z2./z1)./k;

[N,M]=size(sp1);
if N==1
   sp1=sp1';
end

L=length(sp1);
cd=zeros(L,1);
ustar=zeros(L,1);
sp10=0.1.* ones(L,1);
sp2=zeros(L,1);

% remove any zeros in sp1
jzeros=find(sp1==0);
sp1(jzeros)=0.1.*ones(length(jzeros),1);

for m=1:L;
% iterate to find wind speed at 10m
spold=.01;
  for j=1:10;
     c=cdnvera(spold);
     spnew=sp1(m)./(1.+a*sqrt(c));
     if (abs(spnew-spold)) < .001
       break
     else
       spold=spnew;
     end
     sp10(m)=spnew;
  end
end

% compute cd and ustar (using 10m sp) and then sp2
cd=cdnvera(sp10);
ustar=sqrt(cd).*sp10;
sp2=sp1 + b.*ustar;
if N==1
   sp2=sp2';
end
end

