  function tau=stressve(sp,z)
% STRESSVE: computes stress using Vera (1983) neutral drag law.
% tau = STRESSVE(sp,z) computes the neutral wind stress given the wind
% speed at height z following Vera (1983) [see Large, Morzel, and Crawford
% (1995), J. Phys. Oceanog., 25, 2959-2971 (eqn. 8)]. Assumes z a fixed
% scalar, and constant air density (1.22 kg/m^3).
%
%   INPUT:  sp - wind speed (m/s)
%           z - measurement height (m)
%
%   OUTPUT: tau - wind stress (N/m^2)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3/8/97: version 1.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set constants
k=.4;
a=log(z./10)./k;
rho=1.22;

[N,M]=size(sp);
if N==1
   sp=sp';
end

L=length(sp);
cd=zeros(L,1);
tau=zeros(L,1);
sp10=0.1.* ones(L,1);

% remove any zeros in sp
jzeros=find(sp==0);
sp(jzeros)=0.1.*ones(length(jzeros,1);

for m=1:M;
% iterate to find wind speed at 10m
spold=1.;
  for j=1:10;
     c=cdnvera(spold)
     spnew=sp(m)./(1.+a*sqrt(c));
     if (abs(spnew-spold)) < .001
       break
     else
       spold=spnew;
     end
     sp10(m)=spnew;
  end
end

% compute cd and stress using 10m sp
cd=cdnvera(sp10)
tau=rho*cd.*(sp10.^2);

if N==1
   tau=tau';
end

end


