  function [hr,min]=sunrise(mon,da,yr,long,lat)
% SUNRISE: computes the time of sunrise for a specified day and position.
% [hr,min] = SUNRISE(mon,da,yr,long,lat) computes the time of sunrise 
% to the nearest minute in GMT for a calendar day(s) and specified 
% position. 
% 
%   INPUTS: mon - month (e.g., Jan is 1)
%           da - day (e.g., Jan 10th is 10)
%           yr - year (e.g., 1995)
%           lat - latitude (decimal deg)
%           long - longitude (decimal deg) (west is positive)
%
%   OUTPUT: [hr,min]  - sunrise in GMT hours and minutes
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1/29/98: version 2.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% convert calender time to julian yd
j=julianmd(yr,mon,da,0);
j0=julianmd(yr,1,1,0);
yd=j-j0;

% compute solar altitude for entire day
dt=1./8640; % dt = 10 sec.
time=dt.*[0:8640]';
yday=yd+time;
[z,sorad]=soradna1(yday,yr,long,lat);

% determine period of increasing z
bound= 2;
dz=diff(z);
dz=[dz;dz(8640)];
ind=find(abs(z)<bound & dz>0);

% find time of sunrise
zsr=z(ind);
timesr=time(ind);
ind1=find(zsr>=0);
tsr=timesr(ind1(1));

% convert to hr and min
tsrmin=1440.*tsr;
hr=floor(tsrmin./60);
min=floor(rem(tsrmin,60));


